@@ -3,7 +3,7 @@ use utf8;
 use strict;
 use warnings FATAL => 'all';
 
-use Muldis::Rosetta::Interface 0.013000;
+use Muldis::Rosetta::Interface 0.013001;
 
 #use Muldis::Rosetta::Engine::Example::Value 0.000000;
 #use Muldis::Rosetta::Engine::Example::Routines 0.000000;
@@ -17,7 +17,7 @@ use Muldis::Rosetta::Interface 0.013000;
 ###########################################################################
 
 { package Muldis::Rosetta::Engine::Example; # module
-    use version 0.74; our $VERSION = qv('0.13.0');
+    use version 0.74; our $VERSION = qv('0.13.1');
     # Note: This given version applies to all of this file's packages.
 
 ###########################################################################
@@ -34,7 +34,7 @@ sub new_machine {
 ###########################################################################
 
 { package Muldis::Rosetta::Engine::Example::Public::Machine; # class
-    use MooseX::Singleton 0.12;
+    use MooseX::Singleton 0.14;
 
     with 'Muldis::Rosetta::Interface::Machine';
 
@@ -64,35 +64,38 @@ sub new_process {
 ###########################################################################
 
 { package Muldis::Rosetta::Engine::Example::Public::Process; # class
-    use Moose 0.61;
+    use Moose 0.65;
 
-    with 'Muldis::Rosetta::Interface::Process';
-
-    has '_assoc_machine' => (
+    has 'assoc_machine' => (
         is       => 'ro',
         isa      => 'Muldis::Rosetta::Engine::Example::Public::Machine',
-        init_arg => 'assoc_machine',
         required => 1,
     );
 
     has '_inner' => (
         is      => 'rw',
         isa     => 'Muldis::Rosetta::Engine::Example::Runtime::Process',
-# Disabled since Moose::Role's "requires" doesn't recog auto-gen methods.
-#        handles => [qw(
-#            trans_nest_level start_trans commit_trans rollback_trans
-#        )],
+        handles => [qw(
+            trans_nest_level start_trans commit_trans rollback_trans
+        )],
     );
 
     has '_pt_command_lang' => (
-        is  => 'rw',
-        isa => 'Maybe[Str]',
+        is     => 'rw',
+        isa    => 'Maybe[Str]',
+        reader => 'pt_command_lang',
     );
     has '_hd_command_lang' => (
         is  => 'rw',
         isa => 'Maybe[ArrayRef]',
     );
 
+    # This "with" is placed below several "has" so that various accessor
+    # or delegate methods auto-generated by the latter will satisfy the
+    # consumed role's "requires"; this ordering shouldn't be necessary,
+    # but a workaround could be worse.
+    with 'Muldis::Rosetta::Interface::Process';
+
 ###########################################################################
 
 sub BUILD {
@@ -116,20 +119,6 @@ sub BUILD {
 
 ###########################################################################
 
-# Needed since Moose::Role's "requires" doesn't recognize auto-gen methods.
-
-sub assoc_machine {
-    my ($self) = @_;
-    return $self->_assoc_machine();
-}
-
-###########################################################################
-
-sub pt_command_lang {
-    my ($self) = @_;
-    return $self->_pt_command_lang();
-}
-
 sub update_pt_command_lang {
     my ($self, $args) = @_;
     my ($lang) = @{$args}{'lang'};
@@ -140,13 +129,15 @@ sub update_pt_command_lang {
 
 sub hd_command_lang {
     my ($self) = @_;
+    # TODO: actually, the following line needs to clone
+    # this Maybe[ArrayRef] so caller doesn't get copy of our internals.
     return $self->_hd_command_lang();
 }
 
 sub update_hd_command_lang {
     my ($self, $args) = @_;
     my ($lang) = @{$args}{'lang'};
-    # TODO: validate $lang.
+    # TODO: validate and clone $lang.
     $self->_hd_command_lang( $lang );
     return;
 }
@@ -162,13 +153,13 @@ sub execute {
 
     # TODO: validate $lang.
 
-    my $boot_call_seq; # Perl array of what each boot_call parses into
+    my $boot_stmt_seq; # Perl array of what each boot_stmt parses into
 
-    # TODO: parse $source_code into $boot_call_seq
+    # TODO: parse $source_code into $boot_stmt_seq
 
 #    if (ref $source_code) {
-#        $boot_call_seq = Muldis::Rosetta::Engine::Example::HostedData
-#                ->boot_call_seq_from_source_code({
+#        $boot_stmt_seq = Muldis::Rosetta::Engine::Example::HostedData
+#                ->boot_stmt_seq_from_source_code({
 #            'assoc_process' => $self->_inner(),
 #            'source_code' => $source_code,
 #            'exp_command_lang' => $self->_hd_command_lang(),
@@ -176,15 +167,15 @@ sub execute {
 #    }
 
 #    else {
-#        $boot_call_seq = Muldis::Rosetta::Engine::Example::PlainText
-#                ->boot_call_seq_from_source_code({
+#        $boot_stmt_seq = Muldis::Rosetta::Engine::Example::PlainText
+#                ->boot_stmt_seq_from_source_code({
 #            'assoc_process' => $self->_inner(),
 #            'source_code' => $source_code,
 #            'exp_command_lang' => $self->_pt_command_lang(),
 #        });
 #    }
 
-    # TODO: execute $boot_call_seq
+    # TODO: execute $boot_stmt_seq
 
     return;
 }
@@ -231,33 +222,6 @@ sub proc_invo {
     return;
 }
 
-###########################################################################
-
-# Needed since Moose::Role's "requires" doesn't recognize auto-gen methods.
-
-sub trans_nest_level {
-    my ($self) = @_;
-    return $self->_inner()->trans_nest_level();
-}
-
-sub start_trans {
-    my ($self) = @_;
-    $self->_inner()->start_trans();
-    return;
-}
-
-sub commit_trans {
-    my ($self) = @_;
-    $self->_inner()->commit_trans();
-    return;
-}
-
-sub rollback_trans {
-    my ($self) = @_;
-    $self->_inner()->rollback_trans();
-    return;
-}
-
 ###########################################################################
 
     __PACKAGE__->meta()->make_immutable();
@@ -267,14 +231,11 @@ sub rollback_trans {
 ###########################################################################
 
 { package Muldis::Rosetta::Engine::Example::Public::Value; # class
-    use Moose 0.61;
+    use Moose 0.65;
 
-    with 'Muldis::Rosetta::Interface::Value';
-
-    has '_assoc_process' => (
+    has 'assoc_process' => (
         is       => 'ro',
         isa      => 'Muldis::Rosetta::Engine::Example::Public::Process',
-        init_arg => 'assoc_process',
         required => 1,
     );
 
@@ -283,6 +244,12 @@ sub rollback_trans {
         does => 'Muldis::Rosetta::Engine::Example::Value::Universal',
     );
 
+    # This "with" is placed below several "has" so that various accessor
+    # or delegate methods auto-generated by the latter will satisfy the
+    # consumed role's "requires"; this ordering shouldn't be necessary,
+    # but a workaround could be worse.
+    with 'Muldis::Rosetta::Interface::Value';
+
 ###########################################################################
 
 sub BUILD {
@@ -294,7 +261,7 @@ sub BUILD {
 
     # TODO: validate $lang.
 
-    my $assoc_process = $self->_assoc_process();
+    my $assoc_process = $self->assoc_process();
 
     if (ref $source_code) {
 #        $self->_inner( Muldis::Rosetta::Engine::Example::HostedData
@@ -319,15 +286,6 @@ sub BUILD {
 
 ###########################################################################
 
-# Needed since Moose::Role's "requires" doesn't recognize auto-gen methods.
-
-sub assoc_process {
-    my ($self) = @_;
-    return $self->_assoc_process();
-}
-
-###########################################################################
-
 sub pt_source_code {
     my ($self, $args) = @_;
     my ($lang) = @{$args}{'lang'};
@@ -376,7 +334,7 @@ Self-contained reference implementation of a Muldis Rosetta Engine
 
 =head1 VERSION
 
-This document describes Muldis::Rosetta::Engine::Example version 0.13.0 for
+This document describes Muldis::Rosetta::Engine::Example version 0.13.1 for
 Perl 5.
 
 It also describes the same-number versions for Perl 5 of
@@ -503,15 +461,15 @@ Example written in any of the following:
 See L<Muldis::D::Dialect::PTMD_Tiny> for details.
 
 The language name is specified as a Perl character string whose value is
-C<Muldis_D:'http://muldis.com':'0.50.0':PTMD_Tiny>.  No other version
+C<Muldis_D:'http://muldis.com':'0.58.0':PTMD_Tiny>.  No other version
 numbers are currently supported.
 
 =item B<Tiny Perl Hosted Data Muldis D>
 
-See L<Muldis::D::Dialect::HDMD_Perl_Tiny> for details.
+See L<Muldis::D::Dialect::HDMD_Perl5_Tiny> for details.
 
 The language name is specified either as a Perl array whose value is C<[
-'Muldis_D', 'http://muldis.com', '0.50.0', 'HDMD_Perl_Tiny' ]>.  No other
+'Muldis_D', 'http://muldis.com', '0.58.0', 'HDMD_Perl5_Tiny' ]>.  No other
 version numbers are currently supported.
 
 =back
@@ -536,14 +494,14 @@ recommends one that is at least 5.10.0.
 It also requires these Perl 5 packages that are bundled with any version of
 Perl 5.x.y that is at least 5.10.0, and are also on CPAN for separate
 installation by users of earlier Perl versions:
-L<version:ver(0.74..*)|version>.
+L<version-ver(0.74..*)|version>.
 
 It also requires these Perl 5 packages that are on CPAN:
-L<Moose:ver(0.61..*)|Moose>, L<Moose::Role:ver(0.61..*)|Moose::Role>,
-L<MooseX::Singleton:ver(0.12..*)|MooseX::Singleton>.
+L<Moose-ver(0.65..*)|Moose>, L<Moose::Role-ver(0.65..*)|Moose::Role>,
+L<MooseX::Singleton-ver(0.14..*)|MooseX::Singleton>.
 
 It also requires these Perl 5 classes that are in the current distribution:
-L<Muldis::Rosetta::Interface:ver(0.13.0..*)|Muldis::Rosetta::Interface>.
+L<Muldis::Rosetta::Interface-ver(0.13.1..*)|Muldis::Rosetta::Interface>.
 
 =head1 INCOMPATIBILITIES
 
@@ -589,7 +547,7 @@ Darren Duncan (C<perl@DarrenDuncan.net>)
 
 This file is part of the Muldis Rosetta framework.
 
-Muldis Rosetta is Copyright © 2002-2008, Darren Duncan.
+Muldis Rosetta is Copyright © 2002-2009, Darren Duncan.
 
 See the LICENSE AND COPYRIGHT of L<Muldis::Rosetta> for details.
 
